Skip to contents

The canonical "Glasgow" data, as reported in the siena R package for network data analysis. netmediate simply re-exports this data in a more convenient format. See the siena data document for gory details.

Usage

data(glasgow)

Format

A list of three tidygraph::tbl_graph() directed graphs objects, representing the same network measured at three different points in time.

TODO: describe the tidygraphs

Retrieved from https://www.stats.ox.ac.uk/~snijders/siena/Glasgow_data.zip on June 8, 2022.