Skip to contents

Title

Usage

model_mediator_perfect(
  n,
  k = 5,
  ztheta_0 = NULL,
  ztheta_t = NULL,
  ztheta_c = NULL,
  ztheta_tc = NULL,
  expected_degree = NULL
)

Arguments

n

TODO

k

TODO

ztheta_0

TODO

ztheta_t

TODO

ztheta_c

TODO

ztheta_tc

TODO

expected_degree

If specified, the desired expected degree of the graph. Specifying expected_degree simply rescales S to achieve this. Defaults to NULL. Do not specify both expected_degree and expected_density at the same time.

Value

TODO

Examples


ztheta_tc <- rbind(
  c(-1, 2, 0, 0, 0), # treated in block one become twice as central and jump to block two
  c(0, 0, 0, 0, 0),
  c(0, 1, -1, 0, 0), # treated in block three jump to block two
  c(0, 0, 0, 0, 0),
  c(0, 0, 0, 0, 0)
)

perf <- model_mediator_perfect(n = 100, k = 5, ztheta_tc = ztheta_tc)