Skip to contents

In all cases, computes a top-rank decomposition of A, such that \(A \approx U S V^T = Z B Y^T\), where \(Z\) is \(U\) after varimax rotation and \(Y\) is \(V\) after varimax rotation. See vsp::vsp() for details.

Usage

Z(A, rank, ..., degree_normalize = FALSE)

Y(A, rank, ..., degree_normalize = FALSE)

Arguments

A

A matrix() or Matrix::Matrix() object.

rank

Rank of desired decomposition.

...

Arguments passed on to vsp::vsp

x

Either a graph adjacency matrix, igraph::igraph or tidygraph::tbl_graph. If x is a matrix or Matrix::Matrix then x[i, j] should correspond to the edge going from node i to node j.

degree_normalize

Should the regularized graph laplacian be used instead of the raw adjacency matrix? Defaults to TRUE. If center = TRUE, A will first be centered and then normalized.

See also

nodelm, ase_specials