Helper functions for including rotated node embeddings in formulas
Source:R/nodelm.R
vsp_specials.RdIn all cases, computes a top-rank decomposition of A, such that
\(A \approx U S V^T = Z B Y^T\), where \(Z\) is \(U\) after
varimax rotation and \(Y\) is \(V\) after varimax rotation. See
vsp::vsp() for details.
Arguments
- A
A
matrix()orMatrix::Matrix()object.- rank
Rank of desired decomposition.
- ...
Arguments passed on to
vsp::vspxEither a graph adjacency matrix, igraph::igraph or tidygraph::tbl_graph. If
xis a matrix or Matrix::Matrix thenx[i, j]should correspond to the edge going from nodeito nodej.
- degree_normalize
Should the regularized graph laplacian be used instead of the raw adjacency matrix? Defaults to
TRUE. Ifcenter = TRUE,Awill first be centered and then normalized.